package com.example.webapp;

import static android.widget.Toast.LENGTH_SHORT;

import java.io.File;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.graphics.Bitmap;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.webkit.CookieManager;
import android.webkit.CookieSyncManager;
import android.webkit.JsResult;
import android.webkit.WebChromeClient;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.ProgressBar;
import android.widget.Toast;


public class MainActivity extends Activity {
	WebView browser;
	private ProgressBar barraProgreso;
	private ProgressDialog dialogo;
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        
        deleteCache(this);
        comprobarConectividad();
        CookieSyncManager.createInstance(this);         
   	 	CookieManager cookieManager = CookieManager.getInstance();        
   	 	cookieManager.removeAllCookie();
        
   	 	String url = "http://pruebasproyectos.hol.es/index.html";
   	 	browser = (WebView) this.findViewById(R.id.webView1);
		browser.getSettings().setJavaScriptEnabled(true);
		browser.getSettings().setCacheMode(WebSettings.LOAD_NO_CACHE); 
		browser.loadUrl(url);
		
   	 	barraProgreso = (ProgressBar) findViewById(R.id.barraProgreso);

        browser.setWebChromeClient(new WebChromeClient() 
        {
            @Override
            public void onProgressChanged(WebView view, int progreso) 
            {               
            	 barraProgreso.setProgress(0);
		         barraProgreso.setVisibility(View.VISIBLE);
		         MainActivity.this.setProgress(progreso * 1000);
		         barraProgreso.incrementProgressBy(progreso);
		         if (progreso == 100) {
		            barraProgreso.setVisibility(View.GONE);
		         }
            } 
            @Override
            public void onReceivedTitle(WebView view, String title)
            {
                MainActivity.this.setTitle(MainActivity.this.browser.getTitle());
            }
            
            @Override
            public boolean onJsAlert(WebView view, String url, String message, final JsResult result) {
               new AlertDialog.Builder(MainActivity.this).setTitle("Mensaje")
                           .setMessage(message).setPositiveButton
                            (android.R.string.ok,new AlertDialog.OnClickListener() {
                  public void onClick(DialogInterface dialog,int which) {
                     result.confirm();
                  }
               }).setCancelable(false).create().show();
             
               return true;
            }
                       
        });    
        browser.setWebViewClient(new WebViewClient(){
          //gestin de errores
            @Override
            public void onReceivedError(WebView view, int errorCode, String description, String failingUrl) 
            {
                AlertDialog.Builder builder = new AlertDialog.Builder(MainActivity.this);
                builder.setMessage(description).setPositiveButton("Aceptar", null).setTitle("Se ha producido el siguiente error");             
                builder.show();
             }
            
            @Override
            public void onPageStarted(WebView view, String url, Bitmap favicon) {            
               dialogo = new ProgressDialog(MainActivity.this);
               dialogo.setMessage("Cargando...");
               dialogo.setCancelable(true);
               dialogo.show();
            }
          
            @Override
            public void onPageFinished(WebView view, String url) {
               dialogo.dismiss();
            }
            
           @Override
           public boolean shouldOverrideUrlLoading(WebView view, String url) {
                 return false;
           }
        });
        
        
        
    }
    private boolean comprobarConectividad() {
    	   ConnectivityManager connectivityManager = (ConnectivityManager) this.getSystemService(Context.CONNECTIVITY_SERVICE);
    	   NetworkInfo info = connectivityManager.getActiveNetworkInfo();
    	   if ((info == null || !info.isConnected() || !info.isAvailable())) {
    	      Toast.makeText(MainActivity.this,"No dispone de conexin a Internet...\nCompruebe la conectividad de su smartphone.", Toast.LENGTH_LONG).show();
    	      return false;
    	   }
    	   return true;
    	}
    
    public static void deleteCache(Context context) {
        try {
            File dir = context.getCacheDir();
            if (dir != null && dir.isDirectory()) {
                deleteDir(dir);
            }
        } catch (Exception e) {}
    }

    public static boolean deleteDir(File dir) {
        if (dir != null && dir.isDirectory()) {
            String[] children = dir.list();
            for (int i = 0; i < children.length; i++) {
                boolean success = deleteDir(new File(dir, children[i]));
                if (!success) {
                    return false;
                }
            }
        }
        return dir.delete();
    }
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();
        if (id == R.id.action_settings) {
        	// Show a toast
            Toast.makeText(getApplicationContext(),"Ha pulsado AYUDA", LENGTH_SHORT).show();
            return true;
        }
        if (id == R.id.salir){
        	new AlertDialog.Builder(this)
            .setIcon(R.drawable.logo)
            .setTitle("Salir")
            .setMessage("Est seguro que desea salir de la aplicacin?")
            .setPositiveButton("Si", new DialogInterface.OnClickListener()
            {
                @SuppressWarnings("deprecation")
				@Override
                public void onClick(DialogInterface dialog, int which) {
                	finish();    
                }

            })
            .setNegativeButton("No", null)
            .show();  
        }
        return super.onOptionsItemSelected(item);
    }
    
   
    
    @Override
    public void onBackPressed()
    {
        
    }
}
